<?php
/**
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\Storelocator\Controller\PickUpInStore;

use \Magento\Framework\Exception\NotFoundException;

/**
 * Responsible for loading page content.
 *
 * This is a basic controller that only loads the corresponding layout file. It may duplicate other such
 * controllers, and thus it is considered tech debt. This code duplication will be resolved in future releases.
 */
class ConfirmAction extends \Magento\Framework\App\Action\Action
{
    protected $jsonResultFactory;
    protected $helper;
    protected $_order;



    public function __construct(
        \Magento\Framework\App\Action\Context $context,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        \FiloBlu\Storelocator\Helper\Data $helper,
        \Magento\Sales\Api\Data\OrderInterface $order,
        \Magento\Framework\Stdlib\DateTime\DateTime $date
    )
    {
        $this->resultJsonFactory = $resultJsonFactory;
        $this->helper = $helper;
        $this->_order = $order;
        $this->date = $date;
        parent::__construct($context);
    }


    public function execute()
    {

      $params = $this->getRequest()->getParams();

        if (!$this->helper->getConfig('carriers/pickupinstore/active') || !isset($params["increment_id"]) || !$params["increment_id"] || !isset($params["hash"]) || !$params["hash"]) {
            return $this->_forward('noRoute');
        }

        $this->_order->loadByIncrementId($params["increment_id"]);

        if ($this->_order->getId() && $this->_order->getPickupInStoreHash() == $params["hash"] && $this->_order->getShippingMethod() == "pickupinstore_pickupinstore") {
          $this->_order->setPickupInStoreConfirmDate($this->date->gmtDate());
          $this->_order->save();
          $resultJson = $this->resultJsonFactory->create();
          $resultJson->setData(["message" =>__("You confirmed that the order ") . $params["increment_id"] . __(" was withdrawn by the customer.")]);
          $this->_eventManager->dispatch('filoblu_storelocator_pickupinstore_confirm', ['order' => $this->_order]);

          return $resultJson;
        }
        else {
          return $this->_forward('noRoute');
        }
    }
}
